@@ -102,7 +102,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif re.match(r"^-a", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
@@ -115,7 +115,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif sys.argv[1] == '--block':
                 check_root()
                 for arg in sys.argv[1:]:
@@ -126,7 +126,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif re.match(r"^-b", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
@@ -139,7 +139,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif sys.argv[1] == '--redirect':
                 check_root()
                 for arg in sys.argv[1:]:
@@ -151,7 +151,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif re.match(r"^-r", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
@@ -165,7 +165,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif sys.argv[1] == '--delete-rule':
                 check_root()
                 for arg in sys.argv[1:]:
@@ -176,7 +176,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif re.match(r"^-d", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
@@ -189,7 +189,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one domain')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
             elif sys.argv[1] == '--list-rules':
                 if '-s' in sys.argv or '--standard' in sys.argv:
                     standard = True
@@ -236,7 +236,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -274,7 +274,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv or 'y' in sys.argv[1]:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -288,7 +288,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -304,7 +304,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv or 'y' in sys.argv[1]:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -317,7 +317,7 @@ def run() -> None:
                 if count == 0:
                     update_all_filters(database, tmp_dir, force=force)
                 with sqlite3.connect(database) as db:
-                    update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                    update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -332,7 +332,7 @@ def run() -> None:
                 if count == 0:
                     update_all_filters(database, tmp_dir, force=force)
                 with sqlite3.connect(database) as db:
-                    update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                    update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv or 'y' in sys.argv[1]:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -354,7 +354,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -378,7 +378,7 @@ def run() -> None:
                     sys.exit('Error: please specify at least one filter ID')
                 else:
                     with sqlite3.connect(database) as db:
-                        update_hosts(hosts, db, default_hosts, default_ip, force=force)
+                        update_hosts(hosts, db, default_hosts, default_ip, force=True)
                 if '-y' in sys.argv or '--sync' in sys.argv or 'y' in sys.argv[1]:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
@@ -502,7 +502,7 @@ def run_converter() -> None:
                     sys.exit(f'Error: file not found: "{file_to_scan}"')
                 else:
                     with open(file_to_scan, 'rt') as f:
-                        print(f' => Syntax detected: {detect_syntax(f)}')
+                        print(f' ==> Syntax detected: {detect_syntax(f)}')
             else:
                 input_file = None
                 output_file = None
