@@ -57,9 +57,9 @@ remote_repo_mirror = [
 ]
 default_ip = '127.0.0.1'
 
-if os.getenv('TERMUX_VERSION') is not None:
-    tmp_dir = os.path.join(os.getenv('TMPDIR'), 'tblock')
-    lib_dir = os.path.join(os.getenv('PREFIX'), 'tblock')
+if os.path.isdir('/data/data/com.termux/files/usr'):
+    tmp_dir = os.path.join('/data/data/com.termux/files/usr/tmp', 'tblock')
+    lib_dir = os.path.join('/data/data/com.termux/files/usr/lib', 'tblock')
 else:
     lib_dir = '/var/lib/tblock/'
     tmp_dir = '/tmp/tblock/'
